@@ -6,6 +6,7 @@
 #include <config.h>
 
 #include <inttypes.h>
+#include <stddef.h>  // for size_t
 #include <stdint.h>
 #include <string.h>
 
@@ -61,34 +62,9 @@ static const char* expected_type_names[] = {"object", "function", "string"};
 static_assert(G_N_ELEMENTS(expected_type_names) == ExpectedType::LAST,
               "Names must match the values in ExpectedType");
 
-// A helper function to retrieve array lengths from a GIArgument (letting the
-// compiler generate good instructions in case of big endian machines)
-[[nodiscard]] size_t gjs_g_argument_get_array_length(GITypeTag tag,
-                                                     GIArgument* arg) {
-    switch (tag) {
-        case GI_TYPE_TAG_INT8:
-            return gjs_arg_get<int8_t>(arg);
-        case GI_TYPE_TAG_UINT8:
-            return gjs_arg_get<uint8_t>(arg);
-        case GI_TYPE_TAG_INT16:
-            return gjs_arg_get<int16_t>(arg);
-        case GI_TYPE_TAG_UINT16:
-            return gjs_arg_get<uint16_t>(arg);
-        case GI_TYPE_TAG_INT32:
-            return gjs_arg_get<int32_t>(arg);
-        case GI_TYPE_TAG_UINT32:
-            return gjs_arg_get<uint32_t>(arg);
-        case GI_TYPE_TAG_INT64:
-            return gjs_arg_get<int64_t>(arg);
-        case GI_TYPE_TAG_UINT64:
-            return gjs_arg_get<uint64_t>(arg);
-        default:
-            g_assert_not_reached();
-    }
-}
-
-static void gjs_g_argument_set_array_length(GITypeTag tag, GIArgument* arg,
-                                            size_t value) {
+static constexpr void gjs_g_argument_set_array_length(GITypeTag tag,
+                                                      GIArgument* arg,
+                                                      size_t value) {
     switch (tag) {
         case GI_TYPE_TAG_INT8:
             gjs_arg_set<int8_t>(arg, value);
@@ -166,7 +142,10 @@ struct String {
 };
 
 struct TypeInfo {
-    constexpr const GITypeInfo* type_info() const { return &m_type_info; }
+    constexpr GITypeInfo* type_info() const {
+        // Should be const GITypeInfo*, but G-I APIs won't accept that
+        return const_cast<GITypeInfo*>(&m_type_info);
+    }
 
     GITypeInfo m_type_info;
 };
@@ -205,7 +184,8 @@ struct Positioned {
         m_arg_pos = pos;
     }
 
-    bool set_out_parameter(GjsFunctionCallState* state, GIArgument* arg) {
+    constexpr bool set_out_parameter(GjsFunctionCallState* state,
+                                     GIArgument* arg) {
         gjs_arg_unset<void*>(&state->out_cvalue(m_arg_pos));
         gjs_arg_set(arg, &gjs_arg_member<void*>(&state->out_cvalue(m_arg_pos)));
         return true;
@@ -235,35 +215,34 @@ struct BaseInfo {
 };
 
 // boxed / union / GObject
-struct GTypedType {
-    explicit GTypedType(GType gtype) : m_gtype(gtype) {}
-    constexpr GType gtype() const { return m_gtype; }
-
- protected:
-    GType m_gtype;
-};
-
-struct RegisteredType : GTypedType {
+struct RegisteredType {
     RegisteredType(GType gtype, GIInfoType info_type)
-        : GTypedType(gtype), m_info_type(info_type) {}
+        : m_gtype(gtype), m_info_type(info_type) {}
     explicit RegisteredType(GIBaseInfo* info)
-        : GTypedType(g_registered_type_info_get_g_type(info)),
+        : m_gtype(g_registered_type_info_get_g_type(info)),
           m_info_type(g_base_info_get_type(info)) {
         g_assert(m_gtype != G_TYPE_NONE &&
                  "Use RegisteredInterface for this type");
     }
 
+    constexpr GType gtype() const { return m_gtype; }
+
+    GType m_gtype;
     GIInfoType m_info_type : 5;
 };
 
-struct RegisteredInterface : BaseInfo, GTypedType {
+struct RegisteredInterface : BaseInfo {
     explicit RegisteredInterface(GIBaseInfo* info)
         : BaseInfo(info, GjsAutoTakeOwnership{}),
-          GTypedType(g_registered_type_info_get_g_type(m_info)) {}
+          m_gtype(g_registered_type_info_get_g_type(m_info)) {}
+
+    constexpr GType gtype() const { return m_gtype; }
+
+    GType m_gtype;
 };
 
 struct Callback : Nullable, BaseInfo {
-    explicit Callback(GIInterfaceInfo* info)
+    constexpr explicit Callback(GIInterfaceInfo* info)
         : BaseInfo(info, GjsAutoTakeOwnership{}),
           m_scope(GI_SCOPE_TYPE_INVALID) {}
 
@@ -594,8 +573,6 @@ struct GBytesIn : BoxedIn {
     using BoxedIn::BoxedIn;
     bool in(JSContext*, GjsFunctionCallState*, GIArgument*,
             JS::HandleValue) override;
-    bool release(JSContext* cx, GjsFunctionCallState* state, GIArgument* in_arg,
-                 GIArgument* out_arg) override;
 };
 
 struct GBytesInTransferNone : GBytesIn {
@@ -735,35 +712,47 @@ struct CallerAllocatesOut : GenericOut, CallerAllocates {
     }
 };
 
-struct BoxedCallerAllocatesOut : CallerAllocatesOut, GTypedType {
-    using GTypedType::GTypedType;
-    bool release(JSContext*, GjsFunctionCallState*, GIArgument*,
-                 GIArgument*) override;
-};
-
 GJS_JSAPI_RETURN_CONVENTION
 bool NotIntrospectable::in(JSContext* cx, GjsFunctionCallState* state,
                            GIArgument*, JS::HandleValue) {
-    static const char* reason_strings[] = {
-        "callback out-argument",
-        "DestroyNotify argument with no callback",
-        "DestroyNotify argument with no user data",
-        "type not supported for (transfer container)",
-        "type not supported for (out caller-allocates)",
-        "boxed type with transfer not registered as a GType",
-        "union type not registered as a GType",
-        "type not supported by introspection",
-    };
-    static_assert(
-        G_N_ELEMENTS(reason_strings) == NotIntrospectableReason::LAST_REASON,
-        "Explanations must match the values in NotIntrospectableReason");
+    const char* reason_string = "invalid introspection";
+
+    switch (m_reason) {
+        case CALLBACK_OUT:
+            reason_string = "callback out-argument";
+            break;
+        case DESTROY_NOTIFY_NO_CALLBACK:
+            reason_string = "DestroyNotify argument with no callback";
+            break;
+        case DESTROY_NOTIFY_NO_USER_DATA:
+            reason_string = "DestroyNotify argument with no user data";
+            break;
+        case INTERFACE_TRANSFER_CONTAINER:
+            reason_string = "type not supported for (transfer container)";
+            break;
+        case OUT_CALLER_ALLOCATES_NON_STRUCT:
+            reason_string = "type not supported for (out caller-allocates)";
+            break;
+        case UNREGISTERED_BOXED_WITH_TRANSFER:
+            reason_string =
+                "boxed type with transfer not registered as a GType";
+            break;
+        case UNREGISTERED_UNION:
+            reason_string = "union type not registered as a GType";
+            break;
+        case UNSUPPORTED_TYPE:
+            reason_string = "type not supported by introspection";
+            break;
+        case LAST_REASON:
+            g_assert_not_reached();
+    }
 
     gjs_throw(cx,
               "Function %s() cannot be called: argument '%s' with type %s is "
               "not introspectable because it has a %s",
               state->display_name().get(), m_arg_name,
               g_type_tag_to_string(g_type_info_get_tag(&m_type_info)),
-              reason_strings[m_reason]);
+              reason_string);
     return false;
 }
 
@@ -1208,7 +1197,6 @@ bool GBytesIn::in(JSContext* cx, GjsFunctionCallState* state, GIArgument* arg,
 
     JS::RootedObject object(cx, &value.toObject());
     if (JS_IsUint8Array(object)) {
-        state->ignore_release.insert(arg);
         gjs_arg_set(arg, gjs_byte_array_get_bytes(object));
         return true;
     }
@@ -1219,15 +1207,6 @@ bool GBytesIn::in(JSContext* cx, GjsFunctionCallState* state, GIArgument* arg,
         cx, object, arg, GI_DIRECTION_IN, GI_TRANSFER_EVERYTHING, G_TYPE_BYTES);
 }
 
-GJS_JSAPI_RETURN_CONVENTION
-bool GBytesIn::release(JSContext* cx, GjsFunctionCallState* state,
-                       GIArgument* in_arg, GIArgument* out_arg) {
-    if (state->ignore_release.erase(in_arg))
-        return BoxedIn::release(cx, state, in_arg, out_arg);
-
-    return BoxedInTransferNone::release(cx, state, in_arg, out_arg);
-}
-
 GJS_JSAPI_RETURN_CONVENTION
 bool InterfaceIn::in(JSContext* cx, GjsFunctionCallState* state,
                      GIArgument* arg, JS::HandleValue value) {
@@ -1348,8 +1327,7 @@ bool ExplicitArrayInOut::out(JSContext* cx, GjsFunctionCallState* state,
     GIArgument* length_arg = &(state->out_cvalue(m_length_pos));
     size_t length = gjs_g_argument_get_array_length(m_tag, length_arg);
 
-    return gjs_value_from_explicit_array(cx, value, &m_type_info, m_transfer,
-                                         arg, length);
+    return gjs_value_from_explicit_array(cx, value, &m_type_info, arg, length);
 }
 
 GJS_JSAPI_RETURN_CONVENTION
@@ -1436,13 +1414,6 @@ bool CallerAllocatesOut::release(JSContext*, GjsFunctionCallState*,
     return true;
 }
 
-GJS_JSAPI_RETURN_CONVENTION
-bool BoxedCallerAllocatesOut::release(JSContext*, GjsFunctionCallState*,
-                                      GIArgument* in_arg, GIArgument*) {
-    g_boxed_free(m_gtype, gjs_arg_steal<void*>(in_arg));
-    return true;
-}
-
 GJS_JSAPI_RETURN_CONVENTION
 bool CallbackIn::release(JSContext*, GjsFunctionCallState*, GIArgument* in_arg,
                          GIArgument* out_arg [[maybe_unused]]) {
@@ -1592,8 +1563,7 @@ std::unique_ptr<T> Argument::make(uint8_t index, const char* name,
 }
 
 //  Needed for unique_ptr with incomplete type
-// COMPAT: in C++20, use default initializers for these bitfields in the header
-ArgsCache::ArgsCache() : m_is_method(false), m_has_return(false) {}
+ArgsCache::ArgsCache() = default;
 ArgsCache::~ArgsCache() = default;
 
 bool ArgsCache::initialize(JSContext* cx, GICallableInfo* callable) {
@@ -2179,18 +2149,6 @@ void ArgsCache::build_arg(uint8_t gi_index, GIDirection direction,
             return;
         }
 
-        if (type_tag == GI_TYPE_TAG_INTERFACE) {
-            GjsAutoBaseInfo interface_info =
-                g_type_info_get_interface(&type_info);
-            GType gtype = g_registered_type_info_get_g_type(interface_info);
-            if (g_type_is_a(gtype, G_TYPE_BOXED)) {
-                auto* gjs_arg = set_argument_auto<Arg::BoxedCallerAllocatesOut>(
-                    common_args, gtype);
-                gjs_arg->m_allocates_size = size;
-                return;
-            }
-        }
-
         auto* gjs_arg = set_argument_auto<Arg::CallerAllocatesOut>(common_args);
         gjs_arg->m_allocates_size = size;
 
