@@ -25,7 +25,7 @@ do_Get_Upstream_Base () {
     echo '-----------------------------------------'
     echo 'Finding common ancestor'
 
-    if git show-branch ci-upstream-base 2> /dev/null; then
+    if git show-branch ci-upstream-base-branch 2> /dev/null; then
         echo "Already found"
         return
     fi
@@ -46,7 +46,7 @@ do_Get_Upstream_Base () {
         git fetch --depth=30 --no-tags upstream "$base_branch"
     fi
 
-    git branch -f ci-upstream-base-branch FETCH_HEAD
+    git branch ci-upstream-base-branch FETCH_HEAD
 
     # Work out the newest common ancestor between the detached HEAD that this CI
     # job has checked out, and the upstream target branch (which will typically
@@ -139,7 +139,7 @@ elif test "$1" = "BUILD"; then
     do_Set_Env
 
     DEFAULT_CONFIG_OPTS="-Dcairo=enabled -Dreadline=enabled -Dprofiler=enabled \
-        -Ddtrace=false -Dsystemtap=false -Dverbose_logs=false"
+        -Ddtrace=false -Dsystemtap=false -Dverbose_logs=false --werror"
     meson _build $DEFAULT_CONFIG_OPTS $CONFIG_OPTS
     ninja -C _build
 
